
Welcome to pirogue's documentation!
===================================

.. toctree::

.. autosummary::
    :toctree: _autosummary

    pirogue.SingleInheritance
    pirogue.MultipleInheritance
    pirogue.SimpleJoins
    pirogue.information_schema
    pirogue.utils.table_parts
    pirogue.utils.select_columns
    pirogue.utils.insert_command
    pirogue.utils.update_command
    pirogue.exceptions
    scripts.pirogue.__main__



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
